@@ -12,9 +12,6 @@
 #include <QFile>
 #include <QRegularExpression>
 #include <QStandardPaths>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <QTextCodec>
-#endif
 
 RenameCategory KDebugSettingsUtil::parseRenameCategory(QString line, const QString &filename)
 {
@@ -54,11 +51,7 @@ RenameCategory::List KDebugSettingsUtil::readRenameCategories(const QString &fil
     } else {
         QString data;
         QTextStream ts(&file);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        ts.setCodec(QTextCodec::codecForName("ISO-8859-1"));
-#else
         ts.setEncoding(QStringConverter::Encoding::Latin1);
-#endif
         while (!ts.atEnd()) {
             data = ts.readLine().simplified();
             const RenameCategory category = parseRenameCategory(data, filename);
@@ -160,10 +153,10 @@ KdeLoggingCategory KDebugSettingsUtil::parseLineKdeLoggingCategory(QString line,
                 defaultSeverity = defaultSeverityCaptured;
                 // qDebug() << " match.captured(1);" << descriptionCaptured;
                 // qDebug() << " match.captured(2);" << defaultCategoryCaptured;
-                qCWarning(KDEBUGSETTINGSCORE_LOG) << "In this file: " << filename << " this line " << line << " still use old format. We need to port it";
+                qCWarning(KDEBUGSETTINGSCORE_LOG) << "In this file: " << filename << " this line " << line << " still uses the old format. We need to port it.";
             }
         } else {
-            qCWarning(KDEBUGSETTINGSCORE_LOG) << "In this file: " << filename << " this line " << line << " still use old format. We need to port it";
+            qCWarning(KDEBUGSETTINGSCORE_LOG) << "In this file: " << filename << " this line " << line << " still uses the old format. We need to port it.";
         }
     }
     category.categoryName = logName;
@@ -183,11 +176,7 @@ KdeLoggingCategory::List KDebugSettingsUtil::readLoggingCategoriesForInserting(c
     } else {
         QString data;
         QTextStream ts(&file);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        ts.setCodec(QTextCodec::codecForName("ISO-8859-1"));
-#else
         ts.setEncoding(QStringConverter::Encoding::Latin1);
-#endif
         while (!ts.atEnd()) {
             data = ts.readLine().simplified();
             const KdeLoggingCategory category = parseLineKdeLoggingCategory(data, filename);
@@ -199,7 +188,7 @@ KdeLoggingCategory::List KDebugSettingsUtil::readLoggingCategoriesForInserting(c
                         break;
                     } else if (cat.categoryName == category.categoryName) {
                         qCWarning(KDEBUGSETTINGSCORE_LOG)
-                            << "Duplicate categories, it's a bug. Please verify: category:" << cat.categoryName << " filename : " << filename;
+                            << "Duplicate categories, it is a bug. Please verify: category:" << cat.categoryName << " filename : " << filename;
                         needToAppend = false;
                     }
                 }
@@ -221,11 +210,7 @@ void KDebugSettingsUtil::readLoggingCategories(const QString &filename, KdeLoggi
     } else {
         QString data;
         QTextStream ts(&file);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        ts.setCodec(QTextCodec::codecForName("ISO-8859-1"));
-#else
         ts.setEncoding(QStringConverter::Encoding::Latin1);
-#endif
         while (!ts.atEnd()) {
             data = ts.readLine().simplified();
             const KdeLoggingCategory category = parseLineKdeLoggingCategory(data, filename);
@@ -238,7 +223,7 @@ void KDebugSettingsUtil::readLoggingCategories(const QString &filename, KdeLoggi
                             break;
                         } else if (cat.categoryName == category.categoryName) {
                             qCWarning(KDEBUGSETTINGSCORE_LOG)
-                                << "Duplicate categories, it's a bug. Please verify: category:" << cat.categoryName << " filename : " << filename;
+                                << "Duplicate categories, it is a bug. Please verify: category:" << cat.categoryName << " filename : " << filename;
                             needToAppend = false;
                         }
                     }
